@@ -1,16 +1,27 @@
 /*====================================================================*
  -  Copyright (C) 2001 Leptonica.  All rights reserved.
- -  This software is distributed in the hope that it will be
- -  useful, but with NO WARRANTY OF ANY KIND.
- -  No author or distributor accepts responsibility to anyone for the
- -  consequences of using this software, or for whether it serves any
- -  particular purpose or works at all, unless he or she says so in
- -  writing.  Everyone is granted permission to copy, modify and
- -  redistribute this source code, for commercial or non-commercial
- -  purposes, with the following restrictions: (1) the origin of this
- -  source code must not be misrepresented; (2) modified versions must
- -  be plainly marked as such; and (3) this notice may not be removed
- -  or altered from any source or modified source distribution.
+ -
+ -  Redistribution and use in source and binary forms, with or without
+ -  modification, are permitted provided that the following conditions
+ -  are met:
+ -  1. Redistributions of source code must retain the above copyright
+ -     notice, this list of conditions and the following disclaimer.
+ -  2. Redistributions in binary form must reproduce the above
+ -     copyright notice, this list of conditions and the following
+ -     disclaimer in the documentation and/or other materials
+ -     provided with the distribution.
+ -
+ -  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ -  ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ -  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ -  A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL ANY
+ -  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ -  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ -  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ -  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
+ -  OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ -  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ -  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *====================================================================*/
 
 /*
@@ -26,8 +37,6 @@
  *    The brick functions all have a pre-allocated pix as the dest.
  */
 
-#include <stdio.h>
-#include <stdlib.h>
 #include "allheaders.h"
 
 l_int32 DoComparisonDwa1(PIX *pixs, PIX *pixt1, PIX *pixt2, PIX *pixt3,
@@ -57,12 +66,11 @@ l_int32 PixCompareDwa(l_int32 size, const char *type, PIX *pixt1, PIX *pixt2,
                                      otherwise, it tests asymmetric b.c. */
 
 
-main(int    argc,
-     char **argv)
+int main(int    argc,
+         char **argv)
 {
-l_int32      i;
-PIX         *pixs, *pixt0, *pixt1, *pixt2, *pixt3, *pixt4, *pixt5, *pixt6;
-static char  mainName[] = "binmorph4_reg";
+l_int32  i;
+PIX     *pixs, *pixt1, *pixt2, *pixt3, *pixt4, *pixt5, *pixt6;
 
     pixs = pixRead("feyn.tif");
 
@@ -81,7 +89,7 @@ static char  mainName[] = "binmorph4_reg";
     pixt4 = pixCreateTemplateNoInit(pixs);
     pixt5 = pixCreateTemplateNoInit(pixs);
     pixt6 = pixCreateTemplateNoInit(pixs);
-    
+
     for (i = 2; i < 64; i++) {
 
 #if 1
@@ -133,7 +141,7 @@ l_int32   fact1, fact2, size;
 
     selectComposableSizes(isize, &fact1, &fact2);
     size = fact1 * fact2;
-    
+
     fprintf(stderr, "..%d..", size);
 
     if (TIMING) startTimer();
@@ -224,7 +232,7 @@ l_int32   fact1, fact2, size;
 
     selectComposableSizes(isize, &fact1, &fact2);
     size = fact1 * fact2;
-    
+
     fprintf(stderr, "..%d..", size);
 
     if (TIMING) startTimer();
@@ -302,7 +310,7 @@ l_int32   fact1, fact2, size;
 
     selectComposableSizes(isize, &fact1, &fact2);
     size = fact1 * fact2;
-    
+
     fprintf(stderr, "..%d..", size);
 
     if (TIMING) startTimer();
@@ -382,7 +390,7 @@ l_int32   fact1, fact2, size;
 
     selectComposableSizes(isize, &fact1, &fact2);
     size = fact1 * fact2;
-    
+
     fprintf(stderr, "..%d..", size);
 
     if (TIMING) startTimer();
@@ -460,7 +468,7 @@ l_int32   fact1, fact2, size;
 
     selectComposableSizes(isize, &fact1, &fact2);
     size = fact1 * fact2;
-    
+
     fprintf(stderr, "..%d..", size);
 
     if (TIMING) startTimer();
