@@ -41,7 +41,7 @@ char        *filein, *fileout;
 l_uint8     *array1, *array2, *dataout, *dataout2;
 l_int32      i, blocksize, same;
 size_t       nbytes, nout, nout2;
-BBUFFER     *bb, *bb2;
+L_BBUFFER   *bb, *bb2;
 FILE        *fp;
 static char  mainName[] = "buffertest";
 
