@@ -45,8 +45,8 @@
 
 #define  NTIMES             2
 
-int main(int    argc,
-         char **argv)
+l_int32 main(l_int32  argc,
+             char   **argv)
 {
 char        *filein;
 l_int32      i, n, count;
