@@ -72,9 +72,10 @@ static char  mainName[] = "dwamorph2_reg";
     na3 = numaCreate(64);
     na4 = numaCreate(64);
 
+    lept_mkdir("lept/morph");
+
         /*  ---------  dilation  ----------*/
 
-    lept_mkdir("morph");
     for (i = 0; i < nsels / 2; i++)
     {
         sel = selaGetSel(selalinear, i);
@@ -112,7 +113,7 @@ static char  mainName[] = "dwamorph2_reg";
     nac2 = numaWindowedMean(na2, HALFWIDTH);
     nac3 = numaWindowedMean(na3, HALFWIDTH);
     nac4 = numaWindowedMean(na4, HALFWIDTH);
-    gplot = gplotCreate("/tmp/morph/dilate", GPLOT_PNG,
+    gplot = gplotCreate("/tmp/lept/morph/dilate", GPLOT_PNG,
                         "Dilation time vs sel size", "size", "time (ms)");
     gplotAddPlot(gplot, nax, nac1, GPLOT_LINES, "linear rasterop");
     gplotAddPlot(gplot, nax, nac2, GPLOT_LINES, "composite rasterop");
@@ -167,7 +168,7 @@ static char  mainName[] = "dwamorph2_reg";
     nac2 = numaWindowedMean(na2, HALFWIDTH);
     nac3 = numaWindowedMean(na3, HALFWIDTH);
     nac4 = numaWindowedMean(na4, HALFWIDTH);
-    gplot = gplotCreate("/tmp/morph/erode", GPLOT_PNG,
+    gplot = gplotCreate("/tmp/lept/morph/erode", GPLOT_PNG,
                         "Erosion time vs sel size", "size", "time (ms)");
     gplotAddPlot(gplot, nax, nac1, GPLOT_LINES, "linear rasterop");
     gplotAddPlot(gplot, nax, nac2, GPLOT_LINES, "composite rasterop");
@@ -222,7 +223,7 @@ static char  mainName[] = "dwamorph2_reg";
     nac2 = numaWindowedMean(na2, HALFWIDTH);
     nac3 = numaWindowedMean(na3, HALFWIDTH);
     nac4 = numaWindowedMean(na4, HALFWIDTH);
-    gplot = gplotCreate("/tmp/morph/open", GPLOT_PNG,
+    gplot = gplotCreate("/tmp/lept/morph/open", GPLOT_PNG,
                         "Opening time vs sel size", "size", "time (ms)");
     gplotAddPlot(gplot, nax, nac1, GPLOT_LINES, "linear rasterop");
     gplotAddPlot(gplot, nax, nac2, GPLOT_LINES, "composite rasterop");
@@ -277,7 +278,7 @@ static char  mainName[] = "dwamorph2_reg";
     nac2 = numaWindowedMean(na2, HALFWIDTH);
     nac3 = numaWindowedMean(na3, HALFWIDTH);
     nac4 = numaWindowedMean(na4, HALFWIDTH);
-    gplot = gplotCreate("/tmp/morph/close", GPLOT_PNG,
+    gplot = gplotCreate("/tmp/lept/morph/close", GPLOT_PNG,
                         "Closing time vs sel size", "size", "time (ms)");
     gplotAddPlot(gplot, nax, nac1, GPLOT_LINES, "linear rasterop");
     gplotAddPlot(gplot, nax, nac2, GPLOT_LINES, "composite rasterop");
@@ -308,16 +309,16 @@ static char  mainName[] = "dwamorph2_reg";
 
         /* Display the results together */
     pixa = pixaCreate(0);
-    pixs = pixRead("/tmp/morph/dilate.png");
+    pixs = pixRead("/tmp/lept/morph/dilate.png");
     pixaAddPix(pixa, pixs, L_INSERT);
-    pixs = pixRead("/tmp/morph/erode.png");
+    pixs = pixRead("/tmp/lept/morph/erode.png");
     pixaAddPix(pixa, pixs, L_INSERT);
-    pixs = pixRead("/tmp/morph/open.png");
+    pixs = pixRead("/tmp/lept/morph/open.png");
     pixaAddPix(pixa, pixs, L_INSERT);
-    pixs = pixRead("/tmp/morph/close.png");
+    pixs = pixRead("/tmp/lept/morph/close.png");
     pixaAddPix(pixa, pixs, L_INSERT);
     pixt = pixaDisplayTiledInRows(pixa, 32, 1500, 1.0, 0, 40, 3);
-    pixWrite("/tmp/morph/timings.png", pixt, IFF_PNG);
+    pixWrite("/tmp/lept/morph/timings.png", pixt, IFF_PNG);
     pixDisplay(pixt, 100, 100);
     pixDestroy(&pixt);
     pixaDestroy(&pixa);
