@@ -118,7 +118,8 @@ L_REGPARAMS  *rp;
     }
     pixt1 = pixaDisplayTiledAndScaled(pixa, 32, w, 5, 0, 10, 2);
     pixSaveTiled(pixt1, pixaf, 1.0, 1, 20, 0);
-    gplotSimple1(na, GPLOT_PNG, "/tmp/regout/enhance.7", "Average Saturation");
+    gplotSimple1(na, GPLOT_PNG, "/tmp/lept/regout/enhance.7",
+                 "Average Saturation");
     regTestWritePixAndCheck(rp, pixt1, IFF_PNG);  /* 3 */
     pixDisplayWithTitle(pixt1, 900, 100, "Saturation", rp->display);
     numaDestroy(&na);
@@ -154,7 +155,7 @@ L_REGPARAMS  *rp;
         /* Hue constant mapping to lighter background */
     pixa = pixaCreate(11);
     bmf8 = bmfCreate("fonts", 8);
-    pixt0 = pixRead("candelabrum-11.jpg");
+    pixt0 = pixRead("candelabrum.011.jpg");
     composeRGBPixel(230, 185, 144, &srcval);  /* select typical bg pixel */
     for (i = 0; i <= 10; i++) {
         fract = 0.10 * i;
@@ -177,7 +178,7 @@ L_REGPARAMS  *rp;
     pixDestroy(&pixd);
 
         /* Delayed testing of saturation plot */
-    regTestCheckFile(rp, "/tmp/regout/enhance.7.png");  /* 7 */
+    regTestCheckFile(rp, "/tmp/lept/regout/enhance.7.png");  /* 7 */
 
         /* Display results */
     pixd = pixaDisplay(pixaf, 0, 0);
