@@ -1,16 +1,27 @@
 /*====================================================================*
  -  Copyright (C) 2001 Leptonica.  All rights reserved.
- -  This software is distributed in the hope that it will be
- -  useful, but with NO WARRANTY OF ANY KIND.
- -  No author or distributor accepts responsibility to anyone for the
- -  consequences of using this software, or for whether it serves any
- -  particular purpose or works at all, unless he or she says so in
- -  writing.  Everyone is granted permission to copy, modify and
- -  redistribute this source code, for commercial or non-commercial
- -  purposes, with the following restrictions: (1) the origin of this
- -  source code must not be misrepresented; (2) modified versions must
- -  be plainly marked as such; and (3) this notice may not be removed
- -  or altered from any source or modified source distribution.
+ -
+ -  Redistribution and use in source and binary forms, with or without
+ -  modification, are permitted provided that the following conditions
+ -  are met:
+ -  1. Redistributions of source code must retain the above copyright
+ -     notice, this list of conditions and the following disclaimer.
+ -  2. Redistributions in binary form must reproduce the above
+ -     copyright notice, this list of conditions and the following
+ -     disclaimer in the documentation and/or other materials
+ -     provided with the distribution.
+ -
+ -  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ -  ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ -  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ -  A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL ANY
+ -  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ -  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ -  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ -  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
+ -  OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ -  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ -  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *====================================================================*/
 
 /*
@@ -23,10 +34,9 @@
 static PIXA *TestHardlight(const char *file1, const char *file2,
                             L_REGPARAMS *rp);
 
-main(int    argc,
-     char **argv)
+int main(int    argc,
+         char **argv)
 {
-char          fname[256];
 PIX          *pix;
 PIXA         *pixa;
 L_REGPARAMS  *rp;
@@ -56,7 +66,7 @@ TestHardlight(const char   *file1,
               const char   *file2,
               L_REGPARAMS  *rp)
 {
-PIX   *pixs1, *pixs2, *pixr, *pixt1, *pixt2, *pixd;
+PIX   *pixs1, *pixs2, *pixt1, *pixt2, *pixd;
 PIXA  *pixa;
 
     PROCNAME("TestHardlight");
@@ -72,22 +82,22 @@ PIXA  *pixa;
     pixa = pixaCreate(0);
 
         /* ---------- Test not-in-place; no colormaps ----------- */
-    pixSaveTiled(pixs1, pixa, 1, 1, 20, 32);
-    pixSaveTiled(pixs2, pixa, 1, 0, 20, 0);
+    pixSaveTiled(pixs1, pixa, 1.0, 1, 20, 32);
+    pixSaveTiled(pixs2, pixa, 1.0, 0, 20, 0);
     pixd = pixBlendHardLight(NULL, pixs1, pixs2, 0, 0, 1.0);
     regTestWritePixAndCheck(rp, pixd, IFF_PNG);
-    pixSaveTiled(pixd, pixa, 1, 1, 20, 0);
+    pixSaveTiled(pixd, pixa, 1.0, 1, 20, 0);
     pixDestroy(&pixd);
 
     pixt2 = pixConvertTo32(pixs2);
     pixd = pixBlendHardLight(NULL, pixs1, pixt2, 0, 0, 1.0);
     regTestWritePixAndCheck(rp, pixd, IFF_PNG);
-    pixSaveTiled(pixd, pixa, 1, 0, 20, 0);
+    pixSaveTiled(pixd, pixa, 1.0, 0, 20, 0);
     pixDestroy(&pixt2);
     pixDestroy(&pixd);
 
     pixd = pixBlendHardLight(NULL, pixs2, pixs1, 0, 0, 1.0);
-    pixSaveTiled(pixd, pixa, 1, 0, 20, 0);
+    pixSaveTiled(pixd, pixa, 1.0, 0, 20, 0);
     pixDestroy(&pixd);
 
         /* ---------- Test not-in-place; colormaps ----------- */
@@ -97,22 +107,22 @@ PIXA  *pixa;
     else
 /*        pixt2 = pixConvertTo8(pixs2, 1); */
         pixt2 = pixMedianCutQuant(pixs2, 0);
-    pixSaveTiled(pixt1, pixa, 1, 1, 20, 0);
-    pixSaveTiled(pixt2, pixa, 1, 0, 20, 0);
+    pixSaveTiled(pixt1, pixa, 1.0, 1, 20, 0);
+    pixSaveTiled(pixt2, pixa, 1.0, 0, 20, 0);
 
     pixd = pixBlendHardLight(NULL, pixt1, pixs2, 0, 0, 1.0);
     regTestWritePixAndCheck(rp, pixd, IFF_PNG);
-    pixSaveTiled(pixd, pixa, 1, 1, 20, 0);
+    pixSaveTiled(pixd, pixa, 1.0, 1, 20, 0);
     pixDestroy(&pixd);
 
     pixd = pixBlendHardLight(NULL, pixt1, pixt2, 0, 0, 1.0);
     regTestWritePixAndCheck(rp, pixd, IFF_PNG);
-    pixSaveTiled(pixd, pixa, 1, 0, 20, 0);
+    pixSaveTiled(pixd, pixa, 1.0, 0, 20, 0);
     pixDestroy(&pixd);
 
     pixd = pixBlendHardLight(NULL, pixt2, pixt1, 0, 0, 1.0);
     regTestWritePixAndCheck(rp, pixd, IFF_PNG);
-    pixSaveTiled(pixd, pixa, 1, 0, 20, 0);
+    pixSaveTiled(pixd, pixa, 1.0, 0, 20, 0);
     pixDestroy(&pixt1);
     pixDestroy(&pixt2);
     pixDestroy(&pixd);
@@ -120,21 +130,21 @@ PIXA  *pixa;
         /* ---------- Test in-place; no colormaps ----------- */
     pixBlendHardLight(pixs1, pixs1, pixs2, 0, 0, 1.0);
     regTestWritePixAndCheck(rp, pixs1, IFF_PNG);
-    pixSaveTiled(pixs1, pixa, 1, 1, 20, 0);
+    pixSaveTiled(pixs1, pixa, 1.0, 1, 20, 0);
     pixDestroy(&pixs1);
 
     pixs1 = pixRead(file1);
     pixt2 = pixConvertTo32(pixs2);
     pixBlendHardLight(pixs1, pixs1, pixt2, 0, 0, 1.0);
     regTestWritePixAndCheck(rp, pixs1, IFF_PNG);
-    pixSaveTiled(pixs1, pixa, 1, 0, 20, 0);
+    pixSaveTiled(pixs1, pixa, 1.0, 0, 20, 0);
     pixDestroy(&pixt2);
     pixDestroy(&pixs1);
 
     pixs1 = pixRead(file1);
     pixBlendHardLight(pixs2, pixs2, pixs1, 0, 0, 1.0);
     regTestWritePixAndCheck(rp, pixs2, IFF_PNG);
-    pixSaveTiled(pixs2, pixa, 1, 0, 20, 0);
+    pixSaveTiled(pixs2, pixa, 1.0, 0, 20, 0);
     pixDestroy(&pixs2);
 
     pixDestroy(&pixs1);
