@@ -49,19 +49,21 @@
 int main(int    argc,
          char **argv)
 {
-l_int32      i, j, w, h, wpls, n, binsize, binstart, nbins;
+l_int32      i, n, binsize, binstart, nbins;
 l_float32    pi, val, angle, xval, yval, x0, y0, rank, startval, fbinsize;
 l_float32    minval, maxval, meanval, median, variance, rankval;
 GPLOT       *gplot;
 NUMA        *na, *nahisto, *nax, *nay, *nap, *nasx, *nasy;
 NUMA        *nadx, *nady, *nafx, *nafy, *na1, *na2, *na3, *na4;
-PIX         *pix, *pixs, *pix1, *pix2, *pix3, *pix4, *pix5, *pixg, *pixd;
+PIX         *pixs, *pix1, *pix2, *pix3, *pix4, *pix5, *pixd;
 PIXA        *pixa;
 static char  mainName[] = "numa1_reg";
 
     if (argc != 1)
         return ERROR_INT(" Syntax:  numa1_reg", mainName, 1);
 
+    lept_mkdir("lept");
+
     /* -------------------------------------------------------------------*
      *                            Histograms                              *
      * -------------------------------------------------------------------*/
@@ -77,7 +79,7 @@ static char  mainName[] = "numa1_reg";
     nahisto = numaMakeHistogramClipped(na, 6, 2000);
     nbins = numaGetCount(nahisto);
     nax = numaMakeSequence(0, 1, nbins);
-    gplot = gplotCreate("/tmp/historoot1", GPLOT_X11, "example histo 1",
+    gplot = gplotCreate("/tmp/lept/numa_histo1", GPLOT_X11, "example histo 1",
                         "i", "histo[i]");
     gplotAddPlot(gplot, nax, nahisto, GPLOT_LINES, "sine");
     gplotMakeOutput(gplot);
@@ -89,7 +91,7 @@ static char  mainName[] = "numa1_reg";
     nbins = numaGetCount(nahisto);
     nax = numaMakeSequence(binstart, binsize, nbins);
     fprintf(stderr, " binsize = %d, binstart = %d\n", binsize, binstart);
-    gplot = gplotCreate("/tmp/historoot2", GPLOT_X11, "example histo 2",
+    gplot = gplotCreate("/tmp/lept/numa_histo2", GPLOT_X11, "example histo 2",
                         "i", "histo[i]");
     gplotAddPlot(gplot, nax, nahisto, GPLOT_LINES, "sine");
     gplotMakeOutput(gplot);
@@ -101,7 +103,7 @@ static char  mainName[] = "numa1_reg";
     nbins = numaGetCount(nahisto);
     nax = numaMakeSequence(0, binsize, nbins);
     fprintf(stderr, " binsize = %d, binstart = %d\n", binsize, 0);
-    gplot = gplotCreate("/tmp/historoot3", GPLOT_X11, "example histo 3",
+    gplot = gplotCreate("/tmp/lept/numa_histo3", GPLOT_X11, "example histo 3",
                         "i", "histo[i]");
     gplotAddPlot(gplot, nax, nahisto, GPLOT_LINES, "sine");
     gplotMakeOutput(gplot);
@@ -115,7 +117,7 @@ static char  mainName[] = "numa1_reg";
     nax = numaMakeSequence(startval, fbinsize, nbins);
     fprintf(stderr, " binsize = %7.4f, binstart = %8.3f\n",
             fbinsize, startval);
-    gplot = gplotCreate("/tmp/historoot4", GPLOT_X11, "example histo 4",
+    gplot = gplotCreate("/tmp/lept/numa_histo4", GPLOT_X11, "example histo 4",
                         "i", "histo[i]");
     gplotAddPlot(gplot, nax, nahisto, GPLOT_LINES, "sine");
     gplotMakeOutput(gplot);
@@ -149,11 +151,11 @@ static char  mainName[] = "numa1_reg";
     na = pixGetGrayHistogramMasked(pixs, NULL, 0, 0, 1);
 /*    numaWriteStream(stderr, na); */
     nasy = numaGetPartialSums(na);
-    gplotSimple1(nasy, GPLOT_X11, "/tmp/introot1", "partial sums");
-    gplotSimple1(na, GPLOT_X11, "/tmp/introot2", "simple test");
+    gplotSimple1(nasy, GPLOT_X11, "/tmp/lept/numa_int1", "partial sums");
+    gplotSimple1(na, GPLOT_X11, "/tmp/lept/numa_int2", "simple test");
     numaInterpolateEqxInterval(0.0, 1.0, na, L_LINEAR_INTERP,
                                0.0, 255.0, 15, &nax, &nay);
-    gplot = gplotCreate("/tmp/introot3", GPLOT_X11, "test interpolation",
+    gplot = gplotCreate("/tmp/lept/numa_int3", GPLOT_X11, "test interpolation",
                         "pix val", "num pix");
     gplotAddPlot(gplot, nax, nay, GPLOT_LINES, "plot 1");
     gplotMakeOutput(gplot);
@@ -172,10 +174,10 @@ static char  mainName[] = "numa1_reg";
     nasy = numaGetPartialSums(na);
     numaInsertNumber(nasy, 0, 0.0);
     nasx = numaMakeSequence(0.0, 1.0, 257);
-/*    gplotSimple1(nasy, GPLOT_X11, "/tmp/nasyroot", "partial sums"); */
+/*    gplotSimple1(nasy, GPLOT_X11, "/tmp/numa/nasy", "partial sums"); */
     numaInterpolateArbxInterval(nasx, nasy, L_LINEAR_INTERP,
                                 10.0, 250.0, 23, &nax, &nay);
-    gplot = gplotCreate("/tmp/introot4", GPLOT_X11, "arbx interpolation",
+    gplot = gplotCreate("/tmp/lept/numa_int4", GPLOT_X11, "arbx interpolation",
                         "pix val", "cum num pix");
     gplotAddPlot(gplot, nax, nay, GPLOT_LINES, "plot 1");
     gplotMakeOutput(gplot);
@@ -195,7 +197,7 @@ static char  mainName[] = "numa1_reg";
     nasy = numaGetPartialSums(na);
     numaInsertNumber(nasy, 0, 0.0);
     nasx = numaMakeSequence(0.0, 1.0, 257);
-/*    gplotSimple1(nasy, GPLOT_X11, "/tmp/nasyroot", "partial sums"); */
+/*    gplotSimple1(nasy, GPLOT_X11, "/tmp/numa/nasy", "partial sums"); */
     nax = numaMakeSequence(15.0, (250.0 - 15.0) / 23.0, 24);
     n = numaGetCount(nax);
     nay = numaCreate(n);
@@ -204,7 +206,7 @@ static char  mainName[] = "numa1_reg";
         numaInterpolateArbxVal(nasx, nasy, L_QUADRATIC_INTERP, xval, &yval);
         numaAddNumber(nay, yval);
     }
-    gplot = gplotCreate("/tmp/introot5", GPLOT_X11, "arbx interpolation",
+    gplot = gplotCreate("/tmp/lept/numa_int5", GPLOT_X11, "arbx interpolation",
                         "pix val", "cum num pix");
     gplotAddPlot(gplot, nax, nay, GPLOT_LINES, "plot 1");
     gplotMakeOutput(gplot);
@@ -221,7 +223,7 @@ static char  mainName[] = "numa1_reg";
         /* Test interpolation */
     nasx = numaRead("testangle.na");
     nasy = numaRead("testscore.na");
-    gplot = gplotCreate("/tmp/introot6", GPLOT_X11, "arbx interpolation",
+    gplot = gplotCreate("/tmp/lept/numa_int6", GPLOT_X11, "arbx interpolation",
                         "angle", "score");
     numaInterpolateArbxInterval(nasx, nasy, L_LINEAR_INTERP,
                                 -2.00, 0.0, 50, &nax, &nay);
@@ -235,7 +237,7 @@ static char  mainName[] = "numa1_reg";
     numaDestroy(&nay);
     gplotMakeOutput(gplot);
     gplotDestroy(&gplot);
-    gplot = gplotCreate("/tmp/introot7", GPLOT_X11, "arbx interpolation",
+    gplot = gplotCreate("/tmp/lept/numa_int7", GPLOT_X11, "arbx interpolation",
                         "angle", "score");
     numaInterpolateArbxInterval(nasx, nasy, L_LINEAR_INTERP,
                                 -1.2, -0.8, 50, &nax, &nay);
@@ -259,7 +261,7 @@ static char  mainName[] = "numa1_reg";
     nasy = numaRead("testscore.na");
         /* ---------- Plot the derivative ---------- */
     numaDifferentiateInterval(nasx, nasy, -2.0, 0.0, 50, &nadx, &nady);
-    gplot = gplotCreate("/tmp/diffroot1", GPLOT_X11, "derivative",
+    gplot = gplotCreate("/tmp/lept/numa_diff1", GPLOT_X11, "derivative",
                         "angle", "slope");
     gplotAddPlot(gplot, nadx, nady, GPLOT_LINES, "derivative");
     gplotMakeOutput(gplot);
@@ -267,7 +269,7 @@ static char  mainName[] = "numa1_reg";
         /*  ---------- Plot the original function ----------- */
         /*  and the integral of the derivative; the two       */
         /*  should be approximately the same.                 */
-    gplot = gplotCreate("/tmp/diffroot2", GPLOT_X11, "integ-diff",
+    gplot = gplotCreate("/tmp/lept/numa_diff2", GPLOT_X11, "integ-diff",
                         "angle", "val");
     numaInterpolateArbxInterval(nasx, nasy, L_LINEAR_INTERP,
                                 -2.00, 0.0, 50, &nafx, &nafy);
@@ -279,12 +281,12 @@ static char  mainName[] = "numa1_reg";
         /* (Note: this tests robustness of the integrator: we go from
          * i = 0, and choose to have only 1 point in the interpolation
          * there, which is too small and causes the function to bomb out.) */
+    fprintf(stderr, "We must get a 'npts < 2' error here:\n");
     for (i = 0; i < n; i++) {
         numaGetFValue(nadx, i, &xval);
         numaIntegrateInterval(nadx, nady, x0, xval, 2 * i + 1, &yval);
         numaAddNumber(nay, y0 + yval);
     }
-    fprintf(stderr, "It's required to get a 'npts < 2' error here!\n");
     gplotAddPlot(gplot, nafx, nay, GPLOT_LINES, "anti-derivative");
     gplotMakeOutput(gplot);
     gplotDestroy(&gplot);
@@ -305,8 +307,8 @@ static char  mainName[] = "numa1_reg";
     pixs = pixRead("test8.jpg");
     nasy= pixGetGrayHistogramMasked(pixs, NULL, 0, 0, 1);
     numaMakeRankFromHistogram(0.0, 1.0, nasy, 350, &nax, &nay);
-    gplot = gplotCreate("/tmp/rankroot1", GPLOT_X11, "test rank extractor",
-                        "pix val", "rank val");
+    gplot = gplotCreate("/tmp/lept/numa_rank1", GPLOT_X11,
+                        "test rank extractor", "pix val", "rank val");
     gplotAddPlot(gplot, nax, nay, GPLOT_LINES, "plot 1");
     gplotMakeOutput(gplot);
     gplotDestroy(&gplot);
@@ -326,7 +328,7 @@ static char  mainName[] = "numa1_reg";
       numaHistogramGetValFromRank(na, rank, &val);
       numaAddNumber(nap, val);
     }
-    gplotSimple1(nap, GPLOT_X11, "/tmp/rankroot2", "rank value");
+    gplotSimple1(nap, GPLOT_X11, "/tmp/lept/numa_rank2", "rank value");
     numaDestroy(&na);
     numaDestroy(&nap);
     pixDestroy(&pixs);
@@ -336,27 +338,27 @@ static char  mainName[] = "numa1_reg";
      *                           Numa-morphology                          *
      * -------------------------------------------------------------------*/
 #if  DO_ALL
-    na = numaRead("lyra-5.numa");
-    gplotSimple1(na, GPLOT_PNG, "/tmp/lyraroot1", "Original");
+    na = numaRead("lyra.5.na");
+    gplotSimple1(na, GPLOT_PNG, "/tmp/lept/numa_lyra1", "Original");
     na1 = numaErode(na, 21);
-    gplotSimple1(na1, GPLOT_PNG, "/tmp/lyraroot2", "Erosion");
+    gplotSimple1(na1, GPLOT_PNG, "/tmp/lept/numa_lyra2", "Erosion");
     na2 = numaDilate(na, 21);
-    gplotSimple1(na2, GPLOT_PNG, "/tmp/lyraroot3", "Dilation");
+    gplotSimple1(na2, GPLOT_PNG, "/tmp/lept/numa_lyra3", "Dilation");
     na3 = numaOpen(na, 21);
-    gplotSimple1(na3, GPLOT_PNG, "/tmp/lyraroot4", "Opening");
+    gplotSimple1(na3, GPLOT_PNG, "/tmp/lept/numa_lyra4", "Opening");
     na4 = numaClose(na, 21);
-    gplotSimple1(na4, GPLOT_PNG, "/tmp/lyraroot5", "Closing");
+    gplotSimple1(na4, GPLOT_PNG, "/tmp/lept/numa_lyra5", "Closing");
 #ifndef  _WIN32
     sleep(1);
 #else
     Sleep(1000);
 #endif  /* _WIN32 */
     pixa = pixaCreate(5);
-    pix1 = pixRead("/tmp/lyraroot1.png");
-    pix2 = pixRead("/tmp/lyraroot2.png");
-    pix3 = pixRead("/tmp/lyraroot3.png");
-    pix4 = pixRead("/tmp/lyraroot4.png");
-    pix5 = pixRead("/tmp/lyraroot5.png");
+    pix1 = pixRead("/tmp/lept/numa_lyra1.png");
+    pix2 = pixRead("/tmp/lept/numa_lyra2.png");
+    pix3 = pixRead("/tmp/lept/numa_lyra3.png");
+    pix4 = pixRead("/tmp/lept/numa_lyra4.png");
+    pix5 = pixRead("/tmp/lept/numa_lyra5.png");
     pixSaveTiled(pix1, pixa, 1.0, 1, 25, 32);
     pixSaveTiled(pix2, pixa, 1.0, 1, 25, 32);
     pixSaveTiled(pix3, pixa, 1.0, 0, 25, 32);
@@ -364,7 +366,7 @@ static char  mainName[] = "numa1_reg";
     pixSaveTiled(pix5, pixa, 1.0, 0, 25, 32);
     pixd = pixaDisplay(pixa, 0, 0);
     pixDisplay(pixd, 100, 100);
-    pixWrite("/tmp/numamorph.png", pixd, IFF_PNG);
+    pixWrite("/tmp/lept/numa_morph.png", pixd, IFF_PNG);
     numaDestroy(&na);
     numaDestroy(&na1);
     numaDestroy(&na2);
