@@ -54,14 +54,16 @@ PIXA    *pixa;
     for (i = 0; i < NTests; i++)
         GenerateSplitPlot(i);
 
+    lept_mkdir("lept");
+
        /* Read the results back in ...  */
     pixa = pixaCreate(0);
     for (i = 0; i < NTests; i++) {
-        sprintf(buf, "/tmp/junkplot.%d.png", i);
+        sprintf(buf, "/tmp/lept/junkplot.%d.png", i);
         pix = pixRead(buf);
         pixSaveTiled(pix, pixa, 1.0, 1, 25, 32);
         pixDestroy(&pix);
-        sprintf(buf, "/tmp/junkplots.%d.png", i);
+        sprintf(buf, "/tmp/lept/junkplots.%d.png", i);
         pix = pixRead(buf);
         pixSaveTiled(pix, pixa, 1.0, 0, 25, 32);
         pixDestroy(&pix);
@@ -69,7 +71,7 @@ PIXA    *pixa;
 
         /* ... and save into a tiled pix  */
     pix = pixaDisplay(pixa, 0, 0);
-    pixWrite("/tmp/junkotsuplot.png", pix, IFF_PNG);
+    pixWrite("/tmp/lept/junkotsuplot.png", pix, IFF_PNG);
     pixDisplay(pix, 100, 100);
     pixaDestroy(&pixa);
     pixDestroy(&pix);
@@ -85,7 +87,6 @@ l_int32    split;
 l_float32  ave1, ave2, num1, num2, maxnum, maxscore;
 GPLOT     *gplot;
 NUMA      *na1, *na2, *nascore, *nax, *nay;
-PIX       *pixs, *pixd;
 
         /* Generate */
     na1 = MakeGaussian(gaussmean1[i], gaussstdev1[i], gaussfract1[i]);
@@ -106,7 +107,7 @@ PIX       *pixs, *pixd;
     numaReplaceNumber(nay, 1, (l_int32)(0.5 * maxnum));
 
         /* Plot the input histogram with the split location */
-    sprintf(buf, "/tmp/junkplot.%d", i);
+    sprintf(buf, "/tmp/lept/junkplot.%d", i);
     sprintf(title, "Plot %d", i);
     gplot = gplotCreate(buf, GPLOT_PNG,
                         "Histogram: mixture of 2 gaussians",
@@ -119,7 +120,7 @@ PIX       *pixs, *pixd;
     numaDestroy(&na2);
 
         /* Plot the score function */
-    sprintf(buf, "/tmp/junkplots.%d", i);
+    sprintf(buf, "/tmp/lept/junkplots.%d", i);
     sprintf(title, "Plot %d", i);
     gplot = gplotCreate(buf, GPLOT_PNG,
                         "Otsu score function for splitting",
