@@ -54,14 +54,15 @@ L_REGPARAMS  *rp;
     if (regTestSetup(argc, argv, &rp))
         return 1;
 
-    lept_mkdir("pdfseg");
+    lept_rmdir("lept/pdfseg");
+    lept_mkdir("lept/pdfseg");
     baa = boxaaCreate(5);
 
         /* Image region input.  */
     pix1 = pixRead("wet-day.jpg");
     pix2 = pixScaleToSize(pix1, WIDTH, 0);
-    pixWrite("/tmp/pdfseg/0.jpg", pix2, IFF_JFIF_JPEG);
-    regTestCheckFile(rp, "/tmp/pdfseg/0.jpg");   /* 0 */
+    pixWrite("/tmp/lept/pdfseg/0.jpg", pix2, IFF_JFIF_JPEG);
+    regTestCheckFile(rp, "/tmp/lept/pdfseg/0.jpg");   /* 0 */
     box = boxCreate(105, 161, 620, 872);   /* image region */
     boxa1 = boxaCreate(1);
     boxaAddBox(boxa1, box, L_INSERT);
@@ -70,7 +71,7 @@ L_REGPARAMS  *rp;
     pixDestroy(&pix2);
 
         /* Compute image region at w = 2 * WIDTH */
-    pix1 = pixRead("candelabrum-11.jpg");
+    pix1 = pixRead("candelabrum.011.jpg");
     pix2 = pixScaleToSize(pix1, WIDTH, 0);
     pix3 = pixConvertTo1(pix2, 100);
     pix4 = pixExpandBinaryPower2(pix3, 2);  /* w = 2 * WIDTH */
@@ -79,8 +80,8 @@ L_REGPARAMS  *rp;
     pix7 = pixMaskConnComp(pix6, 8, &boxa1);
     pix8 = pixReduceBinary2(pix7, NULL);  /* back to w = WIDTH */
     pix9 = pixBackgroundNormSimple(pix2, pix8, NULL);
-    pixWrite("/tmp/pdfseg/1.jpg", pix9, IFF_JFIF_JPEG);
-    regTestCheckFile(rp, "/tmp/pdfseg/1.jpg");   /* 1 */
+    pixWrite("/tmp/lept/pdfseg/1.jpg", pix9, IFF_JFIF_JPEG);
+    regTestCheckFile(rp, "/tmp/lept/pdfseg/1.jpg");   /* 1 */
     boxa2 = boxaTransform(boxa1, 0, 0, 0.5, 0.5);  /* back to w = WIDTH */
     boxaaAddBoxa(baa, boxa2, L_INSERT);
     pixDestroy(&pix1);
@@ -96,8 +97,8 @@ L_REGPARAMS  *rp;
         /* Use mask to find image region */
     pix1 = pixRead("lion-page.00016.jpg");
     pix2 = pixScaleToSize(pix1, WIDTH, 0);
-    pixWrite("/tmp/pdfseg/2.jpg", pix2, IFF_JFIF_JPEG);
-    regTestCheckFile(rp, "/tmp/pdfseg/2.jpg");   /* 2 */
+    pixWrite("/tmp/lept/pdfseg/2.jpg", pix2, IFF_JFIF_JPEG);
+    regTestCheckFile(rp, "/tmp/lept/pdfseg/2.jpg");   /* 2 */
     pix3 = pixRead("lion-mask.00016.tif");
     pix4 = pixScaleToSize(pix3, WIDTH, 0);
     boxa1 = pixConnComp(pix4, NULL, 8);
@@ -111,8 +112,8 @@ L_REGPARAMS  *rp;
     pix1 = pixRead("rabi.png");
     scalefactor = (l_float32)WIDTH / (l_float32)pixGetWidth(pix1);
     pix2 = pixScaleToGray(pix1, scalefactor);
-    pixWrite("/tmp/pdfseg/3.jpg", pix2, IFF_JFIF_JPEG);
-    regTestCheckFile(rp, "/tmp/pdfseg/3.jpg");   /* 3 */
+    pixWrite("/tmp/lept/pdfseg/3.jpg", pix2, IFF_JFIF_JPEG);
+    regTestCheckFile(rp, "/tmp/lept/pdfseg/3.jpg");   /* 3 */
     pix3 = pixGenHalftoneMask(pix1, NULL, NULL, 0);
     pix4 = pixMorphSequence(pix3, "c20.1 + c1.20", 0);
     boxa1 = pixConnComp(pix4, NULL, 8);
@@ -125,11 +126,11 @@ L_REGPARAMS  *rp;
     boxaDestroy(&boxa1);
 
         /* Page with no image regions */
-    pix1 = pixRead("lucasta-47.jpg");
+    pix1 = pixRead("lucasta.047.jpg");
     pix2 = pixScaleToSize(pix1, WIDTH, 0);
     boxa1 = boxaCreate(1);
-    pixWrite("/tmp/pdfseg/4.jpg", pix2, IFF_JFIF_JPEG);
-    regTestCheckFile(rp, "/tmp/pdfseg/4.jpg");   /* 4 */
+    pixWrite("/tmp/lept/pdfseg/4.jpg", pix2, IFF_JFIF_JPEG);
+    regTestCheckFile(rp, "/tmp/lept/pdfseg/4.jpg");   /* 4 */
     boxaaAddBoxa(baa, boxa1, L_INSERT);
     pixDestroy(&pix1);
     pixDestroy(&pix2);
@@ -137,8 +138,8 @@ L_REGPARAMS  *rp;
         /* Page that is all image */
     pix1 = pixRead("map1.jpg");
     pix2 = pixScaleToSize(pix1, WIDTH, 0);
-    pixWrite("/tmp/pdfseg/5.jpg", pix2, IFF_JFIF_JPEG);
-    regTestCheckFile(rp, "/tmp/pdfseg/5.jpg");   /* 5 */
+    pixWrite("/tmp/lept/pdfseg/5.jpg", pix2, IFF_JFIF_JPEG);
+    regTestCheckFile(rp, "/tmp/lept/pdfseg/5.jpg");   /* 5 */
     h = pixGetHeight(pix2);
     box = boxCreate(0, 0, WIDTH, h);
     boxa1 = boxaCreate(1);
@@ -148,18 +149,17 @@ L_REGPARAMS  *rp;
     pixDestroy(&pix2);
 
         /* Save the boxaa file */
-    boxaaWrite("/tmp/pdfseg/images.baa", baa);
-    regTestCheckFile(rp, "/tmp/pdfseg/images.baa");   /* 6 */
+    boxaaWrite("/tmp/lept/pdfseg/images.baa", baa);
+    regTestCheckFile(rp, "/tmp/lept/pdfseg/images.baa");   /* 6 */
 
         /* Do the conversion */
     l_pdfSetDateAndVersion(FALSE);
-    convertSegmentedFilesToPdf("/tmp/pdfseg", "jpg", 100, L_G4_ENCODE,
+    convertSegmentedFilesToPdf("/tmp/lept/pdfseg", "jpg", 100, L_G4_ENCODE,
                                140, baa, 75, 0.6, "Segmentation Test",
-                               "/tmp/regout/pdfseg.7.pdf");
-    L_INFO("Generated pdf file: /tmp/regout/pdfseg.7.pdf\n", rp->testname);
-    regTestCheckFile(rp, "/tmp/regout/pdfseg.7.pdf");   /* 7 */
+                               "/tmp/lept/regout/pdfseg.7.pdf");
+    L_INFO("Generated pdf file: /tmp/lept/regout/pdfseg.7.pdf\n", rp->testname);
+    regTestCheckFile(rp, "/tmp/lept/regout/pdfseg.7.pdf");   /* 7 */
 
-    lept_rmdir("pdfseg");
     boxaaDestroy(&baa);
     return regTestCleanup(rp);
 }
