@@ -63,15 +63,14 @@ L_REGPARAMS  *rp;
     pixGetDimensions(pixs, &w, &h, NULL);
     factor = L_MAX(1, (l_int32)sqrt((l_float64)(w * h / 20000.0)));
     nbins = 10;
-    pixGetRankColorArray(pixs, nbins, L_SELECT_MIN, factor, &array,
-                         2, "./fonts");
+    pixGetRankColorArray(pixs, nbins, L_SELECT_MIN, factor, &array, 2, 6);
     if (!array)
         return ERROR_INT("\n\n\nFAILURE!\n\n\n", rp->testname, 1);
     for (i = 0; i < nbins; i++)
         fprintf(stderr, "%d: %x\n", i, array[i]);
-    pixd = pixDisplayColorArray(array, nbins, 200, 5, "./fonts");
-    pixWrite("/tmp/regout/rankhisto.0.png", pixd, IFF_PNG);
-    regTestCheckFile(rp, "/tmp/regout/rankhisto.0.png");  /* 0 */
+    pixd = pixDisplayColorArray(array, nbins, 200, 5, 6);
+    pixWrite("/tmp/lept/regout/rankhisto.0.png", pixd, IFF_PNG);
+    regTestCheckFile(rp, "/tmp/lept/regout/rankhisto.0.png");  /* 0 */
     pixDisplayWithTitle(pixd, 100, 100, NULL, rp->display);
     pixDestroy(&pixd);
 
@@ -81,23 +80,23 @@ L_REGPARAMS  *rp;
     for (i = 0; i < nbins; i++)
         pixelLinearMapToTargetColor(array[i], array[nbins - 1],
                                     0xffffff00, &marray[i]);
-    pixd = pixDisplayColorArray(marray, nbins, 200, 5, "./fonts");
-    pixWrite("/tmp/regout/rankhisto.1.png", pixd, IFF_PNG);
-    regTestCheckFile(rp, "/tmp/regout/rankhisto.1.png");  /* 1 */
+    pixd = pixDisplayColorArray(marray, nbins, 200, 5, 6);
+    pixWrite("/tmp/lept/regout/rankhisto.1.png", pixd, IFF_PNG);
+    regTestCheckFile(rp, "/tmp/lept/regout/rankhisto.1.png");  /* 1 */
     pixDisplayWithTitle(pixd, 100, 600, NULL, rp->display);
     pixDestroy(&pixd);
     lept_free(marray);
 
-        /* Save the histogram plots */
 #ifndef  _WIN32
     sleep(2);  /* give gnuplot time to write out the files */
 #else
     Sleep(2000);
 #endif  /* _WIN32 */
+        /* Save the histogram plots */
     pixa = PixSavePlots1();
     pixd = pixaDisplay(pixa, 0, 0);
-    pixWrite("/tmp/regout/rankhisto.2.png", pixd, IFF_PNG);
-    regTestCheckFile(rp, "/tmp/regout/rankhisto.2.png");  /* 2 */
+    pixWrite("/tmp/lept/regout/rankhisto.2.png", pixd, IFF_PNG);
+    regTestCheckFile(rp, "/tmp/lept/regout/rankhisto.2.png");  /* 2 */
     pixDisplayWithTitle(pixd, 100, 600, NULL, rp->display);
     pixaDestroy(&pixa);
     pixDestroy(&pixd);
@@ -105,8 +104,8 @@ L_REGPARAMS  *rp;
         /* Map to the lightest bin; then do TRC adjustment */
     pixt = pixLinearMapToTargetColor(NULL, pixs, array[nbins - 1], 0xffffff00);
     pixd = pixGammaTRC(NULL, pixt, 1.0, 0, 240);
-    pixWrite("/tmp/regout/rankhisto.3.png", pixd, IFF_PNG);
-    regTestCheckFile(rp, "/tmp/regout/rankhisto.3.png");  /* 3 */
+    pixWrite("/tmp/lept/regout/rankhisto.3.png", pixd, IFF_PNG);
+    regTestCheckFile(rp, "/tmp/lept/regout/rankhisto.3.png");  /* 3 */
     pixDisplayWithTitle(pixd, 600, 100, NULL, rp->display);
     pixDestroy(&pixt);
     pixDestroy(&pixd);
@@ -125,26 +124,28 @@ L_REGPARAMS  *rp;
         numaReplaceNumber(na, spike, 200.0);
         nan = numaNormalizeHistogram(na, 1.0);
         numaDiscretizeRankAndIntensity(nan, 10, &narbin, &nai, NULL, NULL);
-        snprintf(fname, sizeof(fname), "/tmp/regout/rtnan%d", i + 1);
+        snprintf(fname, sizeof(fname), "/tmp/lept/regout/rtnan%d", i + 1);
         gplotSimple1(nan, GPLOT_PNG, fname, "Normalized Histogram");
-        snprintf(fname, sizeof(fname), "/tmp/regout/rtnai%d", i + 1);
+        snprintf(fname, sizeof(fname), "/tmp/lept/regout/rtnai%d", i + 1);
         gplotSimple1(nai, GPLOT_PNG, fname, "Intensity vs. rank bin");
-        snprintf(fname, sizeof(fname), "/tmp/regout/rtnarbin%d", i + 1);
+        snprintf(fname, sizeof(fname), "/tmp/lept/regout/rtnarbin%d", i + 1);
         gplotSimple1(narbin, GPLOT_PNG, fname, "LUT: rank bin vs. Intensity");
         numaDestroy(&na);
         numaDestroy(&nan);
         numaDestroy(&narbin);
         numaDestroy(&nai);
     }
+
 #ifndef  _WIN32
     sleep(2);  /* give gnuplot time to write out the files */
 #else
     Sleep(2000);
 #endif  /* _WIN32 */
+
     pixa = PixSavePlots2();
     pixd = pixaDisplay(pixa, 0, 0);
-    pixWrite("/tmp/regout/rankhisto.4.png", pixd, IFF_PNG);
-    regTestCheckFile(rp, "/tmp/regout/rankhisto.4.png");  /* 4 */
+    pixWrite("/tmp/lept/regout/rankhisto.4.png", pixd, IFF_PNG);
+    regTestCheckFile(rp, "/tmp/lept/regout/rankhisto.4.png");  /* 4 */
     pixDisplayWithTitle(pixd, 500, 600, NULL, rp->display);
     pixaDestroy(&pixa);
     pixDestroy(&pixd);
@@ -162,34 +163,33 @@ PIX    *pixt;
 PIXA   *pixa;
 
     pixa = pixaCreate(8);
-    pixt = pixRead("/tmp/regout/rtnan.png");
+    pixt = pixRead("/tmp/lept/regout/rtnan.png");
     pixSaveTiled(pixt, pixa, 1.0, 1, 20, 8);
     pixDestroy(&pixt);
-    pixt = pixRead("/tmp/regout/rtnar.png");
+    pixt = pixRead("/tmp/lept/regout/rtnar.png");
     pixSaveTiled(pixt, pixa, 1.0, 0, 20, 8);
     pixDestroy(&pixt);
-    pixt = pixRead("/tmp/regout/rtnai.png");
+    pixt = pixRead("/tmp/lept/regout/rtnai.png");
     pixSaveTiled(pixt, pixa, 1.0, 0, 20, 8);
     pixDestroy(&pixt);
-    pixt = pixRead("/tmp/regout/rtnarbin.png");
+    pixt = pixRead("/tmp/lept/regout/rtnarbin.png");
     pixSaveTiled(pixt, pixa, 1.0, 1, 20, 8);
     pixDestroy(&pixt);
-    pixt = pixRead("/tmp/regout/rtnabb.png");
+    pixt = pixRead("/tmp/lept/regout/rtnabb.png");
     pixSaveTiled(pixt, pixa, 1.0, 0, 20, 8);
     pixDestroy(&pixt);
-    pixt = pixRead("/tmp/regout/rtnared.png");
+    pixt = pixRead("/tmp/lept/regout/rtnared.png");
     pixSaveTiled(pixt, pixa, 1.0, 1, 20, 8);
     pixDestroy(&pixt);
-    pixt = pixRead("/tmp/regout/rtnagreen.png");
+    pixt = pixRead("/tmp/lept/regout/rtnagreen.png");
     pixSaveTiled(pixt, pixa, 1.0, 0, 20, 8);
     pixDestroy(&pixt);
-    pixt = pixRead("/tmp/regout/rtnablue.png");
+    pixt = pixRead("/tmp/lept/regout/rtnablue.png");
     pixSaveTiled(pixt, pixa, 1.0, 0, 20, 8);
     pixDestroy(&pixt);
     return pixa;
 }
 
-
 static PIXA *
 PixSavePlots2(void)
 {
@@ -197,31 +197,31 @@ PIX    *pixt;
 PIXA   *pixa;
 
     pixa = pixaCreate(9);
-    pixt = pixRead("/tmp/regout/rtnan1.png");
+    pixt = pixRead("/tmp/lept/regout/rtnan1.png");
     pixSaveTiled(pixt, pixa, 1.0, 1, 20, 8);
     pixDestroy(&pixt);
-    pixt = pixRead("/tmp/regout/rtnai1.png");
+    pixt = pixRead("/tmp/lept/regout/rtnai1.png");
     pixSaveTiled(pixt, pixa, 1.0, 0, 20, 8);
     pixDestroy(&pixt);
-    pixt = pixRead("/tmp/regout/rtnarbin1.png");
+    pixt = pixRead("/tmp/lept/regout/rtnarbin1.png");
     pixSaveTiled(pixt, pixa, 1.0, 0, 20, 8);
     pixDestroy(&pixt);
-    pixt = pixRead("/tmp/regout/rtnan2.png");
+    pixt = pixRead("/tmp/lept/regout/rtnan2.png");
     pixSaveTiled(pixt, pixa, 1.0, 1, 20, 8);
     pixDestroy(&pixt);
-    pixt = pixRead("/tmp/regout/rtnai2.png");
+    pixt = pixRead("/tmp/lept/regout/rtnai2.png");
     pixSaveTiled(pixt, pixa, 1.0, 0, 20, 8);
     pixDestroy(&pixt);
-    pixt = pixRead("/tmp/regout/rtnarbin2.png");
+    pixt = pixRead("/tmp/lept/regout/rtnarbin2.png");
     pixSaveTiled(pixt, pixa, 1.0, 0, 20, 8);
     pixDestroy(&pixt);
-    pixt = pixRead("/tmp/regout/rtnan3.png");
+    pixt = pixRead("/tmp/lept/regout/rtnan3.png");
     pixSaveTiled(pixt, pixa, 1.0, 1, 20, 8);
     pixDestroy(&pixt);
-    pixt = pixRead("/tmp/regout/rtnai3.png");
+    pixt = pixRead("/tmp/lept/regout/rtnai3.png");
     pixSaveTiled(pixt, pixa, 1.0, 0, 20, 8);
     pixDestroy(&pixt);
-    pixt = pixRead("/tmp/regout/rtnarbin3.png");
+    pixt = pixRead("/tmp/lept/regout/rtnarbin3.png");
     pixSaveTiled(pixt, pixa, 1.0, 0, 20, 8);
     pixDestroy(&pixt);
     return pixa;
