@@ -32,7 +32,7 @@ TEST_NAME="${TEST_NAME%_reg*}"
 
 case "${TEST_NAME}" in
     colormask|colorspace|dna|enhance|fpix1|kernel|nearline|projection|rankbin|rankhisto)
-        which gnuplot > /dev/null || which wgnuplot > /dev/null || exit 77 ;;
+        which gnuplot > /dev/null || which wgnuplot > /dev/null || exec ${@%${TEST}} /bin/sh -c "exit 77" ;;
 esac
 
 exec ${@%${TEST}} /bin/sh -c "cd \"${srcdir}\" && \"${PWD}/\"${TEST} generate && \"${PWD}/\"${TEST} compare"
