@@ -1,16 +1,27 @@
 /*====================================================================*
  -  Copyright (C) 2001 Leptonica.  All rights reserved.
- -  This software is distributed in the hope that it will be
- -  useful, but with NO WARRANTY OF ANY KIND.
- -  No author or distributor accepts responsibility to anyone for the
- -  consequences of using this software, or for whether it serves any
- -  particular purpose or works at all, unless he or she says so in
- -  writing.  Everyone is granted permission to copy, modify and
- -  redistribute this source code, for commercial or non-commercial
- -  purposes, with the following restrictions: (1) the origin of this
- -  source code must not be misrepresented; (2) modified versions must
- -  be plainly marked as such; and (3) this notice may not be removed
- -  or altered from any source or modified source distribution.
+ -
+ -  Redistribution and use in source and binary forms, with or without
+ -  modification, are permitted provided that the following conditions
+ -  are met:
+ -  1. Redistributions of source code must retain the above copyright
+ -     notice, this list of conditions and the following disclaimer.
+ -  2. Redistributions in binary form must reproduce the above
+ -     copyright notice, this list of conditions and the following
+ -     disclaimer in the documentation and/or other materials
+ -     provided with the distribution.
+ -
+ -  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
+ -  ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
+ -  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
+ -  A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL ANY
+ -  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
+ -  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
+ -  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
+ -  PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
+ -  OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
+ -  NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ -  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *====================================================================*/
 
 /*
@@ -39,11 +50,11 @@
 static const l_int32  BORDER = 150;
 
 
-main(int    argc,
-     char **argv)
+int main(int    argc,
+         char **argv)
 {
 l_int32       w, h, wd, hd;
-l_float32     deg2rad, angle, conf, score;
+l_float32     deg2rad, angle, conf;
 PIX          *pixs, *pixb1, *pixb2, *pixr, *pixf, *pixd, *pixc;
 PIXA         *pixa;
 L_REGPARAMS  *rp;
@@ -63,11 +74,11 @@ L_REGPARAMS  *rp;
         /* Add a border and locate and deskew a 40 degree rotation */
     pixb2 = pixAddBorder(pixb1, BORDER, 0);
     pixGetDimensions(pixb2, &w, &h, NULL);
-    pixSaveTiled(pixb2, pixa, 2, 1, 20, 8);
+    pixSaveTiled(pixb2, pixa, 0.5, 1, 20, 8);
     pixr = pixRotateBySampling(pixb2, w / 2, h / 2,
                                     deg2rad * 40., L_BRING_IN_WHITE);
     regTestWritePixAndCheck(rp, pixr, IFF_PNG);  /* 1 */
-    pixSaveTiled(pixr, pixa, 2, 0, 20, 0);
+    pixSaveTiled(pixr, pixa, 0.5, 0, 20, 0);
     pixFindSkewSweepAndSearchScorePivot(pixr, &angle, &conf, NULL, 1, 1,
                                         0.0, 45.0, 2.0, 0.03,
                                         L_SHEAR_ABOUT_CENTER);
@@ -77,7 +88,7 @@ L_REGPARAMS  *rp;
                                     deg2rad * angle, L_BRING_IN_WHITE);
     pixd = pixRemoveBorder(pixf, BORDER);
     regTestWritePixAndCheck(rp, pixd, IFF_PNG);  /* 2 */
-    pixSaveTiled(pixd, pixa, 2, 0, 20, 0);
+    pixSaveTiled(pixd, pixa, 0.5, 0, 20, 0);
     pixDestroy(&pixr);
     pixDestroy(&pixf);
     pixDestroy(&pixd);
@@ -89,7 +100,7 @@ L_REGPARAMS  *rp;
     pixr = pixRotate(pixb1, deg2rad * 37., L_ROTATE_SAMPLING,
                      L_BRING_IN_WHITE, w, h);
     regTestWritePixAndCheck(rp, pixr, IFF_PNG);  /* 3 */
-    pixSaveTiled(pixr, pixa, 2, 1, 20, 0);
+    pixSaveTiled(pixr, pixa, 0.5, 1, 20, 0);
     startTimer();
     pixFindSkewOrthogonalRange(pixr, &angle, &conf, 2, 1,
                                47.0, 1.0, 0.03, 0.0);
@@ -102,7 +113,7 @@ L_REGPARAMS  *rp;
     pixc = pixCreate(w, h, 1);
     pixRasterop(pixc, 0, 0, w, h, PIX_SRC, pixd, (wd - w) / 2, (hd - h) / 2);
     regTestWritePixAndCheck(rp, pixc, IFF_PNG);  /* 5 */
-    pixSaveTiled(pixc, pixa, 2, 0, 20, 0);
+    pixSaveTiled(pixc, pixa, 0.5, 0, 20, 0);
     pixDestroy(&pixr);
     pixDestroy(&pixf);
     pixDestroy(&pixd);
@@ -135,24 +146,24 @@ L_REGPARAMS  *rp;
 
 #if 0
     if (pixFindSkew(pixs, &angle)) {
-	L_WARNING("skew angle not valid", mainName);
-	exit(1);
+        L_WARNING("skew angle not valid\n", mainName);
+        return 1;
     }
 #endif
 
 #if 0
     if (pixFindSkewSweep(pixs, &angle, SWEEP_REDUCTION,
                          SWEEP_RANGE, SWEEP_DELTA)) {
-	L_WARNING("skew angle not valid", mainName);
-	exit(1);
+        L_WARNING("skew angle not valid\n", mainName);
+        return 1;
     }
 #endif
 
 #if 0
     if (pixFindSkewSweepAndSearch(pixs, &angle, SWEEP_REDUCTION2,
                          SEARCH_REDUCTION, SWEEP_RANGE2, SWEEP_DELTA2,
-			 SEARCH_MIN_DELTA)) {
-	L_WARNING("skew angle not valid", mainName);
-	exit(1);
+                         SEARCH_MIN_DELTA)) {
+        L_WARNING("skew angle not valid\n", mainName);
+        return 1;
     }
 #endif
