@@ -274,6 +274,9 @@ l_float32  h;
 
     PROCNAME("convertRGBToHSV");
 
+    if (phval) *phval = 0;
+    if (psval) *psval = 0;
+    if (pvval) *pvval = 0;
     if (!phval || !psval || !pvval)
         return ERROR_INT("&hval, &sval, &vval not all defined", procName, 1);
 
@@ -331,6 +334,9 @@ l_float32 h, f, s;
 
     PROCNAME("convertHSVToRGB");
 
+    if (prval) *prval = 0;
+    if (pgval) *pgval = 0;
+    if (pbval) *pbval = 0;
     if (!prval || !pgval || !pbval)
         return ERROR_INT("&rval, &gval, &bval not all defined", procName, 1);
 
@@ -693,8 +699,8 @@ PIX       *pixt, *pixd;
 
         /* Set up LUTs for hue and saturation.  These have the value 1
          * within the specified intervals of hue and saturation. */
-    hlut = (l_int32 *)CALLOC(240, sizeof(l_int32));
-    slut = (l_int32 *)CALLOC(256, sizeof(l_int32));
+    hlut = (l_int32 *)LEPT_CALLOC(240, sizeof(l_int32));
+    slut = (l_int32 *)LEPT_CALLOC(256, sizeof(l_int32));
     sstart = L_MAX(0, satcenter - sathw);
     send = L_MIN(255, satcenter + sathw);
     for (i = sstart; i <= send; i++)
@@ -739,8 +745,8 @@ PIX       *pixt, *pixd;
         }
     }
 
-    FREE(hlut);
-    FREE(slut);
+    LEPT_FREE(hlut);
+    LEPT_FREE(slut);
     pixDestroy(&pixt);
     return pixd;
 }
@@ -790,8 +796,8 @@ PIX       *pixt, *pixd;
 
         /* Set up LUTs for hue and maximum intensity (val).  These have
          * the value 1 within the specified intervals of hue and value. */
-    hlut = (l_int32 *)CALLOC(240, sizeof(l_int32));
-    vlut = (l_int32 *)CALLOC(256, sizeof(l_int32));
+    hlut = (l_int32 *)LEPT_CALLOC(240, sizeof(l_int32));
+    vlut = (l_int32 *)LEPT_CALLOC(256, sizeof(l_int32));
     vstart = L_MAX(0, valcenter - valhw);
     vend = L_MIN(255, valcenter + valhw);
     for (i = vstart; i <= vend; i++)
@@ -836,8 +842,8 @@ PIX       *pixt, *pixd;
         }
     }
 
-    FREE(hlut);
-    FREE(vlut);
+    LEPT_FREE(hlut);
+    LEPT_FREE(vlut);
     pixDestroy(&pixt);
     return pixd;
 }
@@ -887,8 +893,8 @@ PIX       *pixt, *pixd;
         /* Set up LUTs for saturation and max intensity (val).
          * These have the value 1 within the specified intervals of
          * saturation and max intensity. */
-    slut = (l_int32 *)CALLOC(256, sizeof(l_int32));
-    vlut = (l_int32 *)CALLOC(256, sizeof(l_int32));
+    slut = (l_int32 *)LEPT_CALLOC(256, sizeof(l_int32));
+    vlut = (l_int32 *)LEPT_CALLOC(256, sizeof(l_int32));
     sstart = L_MAX(0, satcenter - sathw);
     send = L_MIN(255, satcenter + sathw);
     vstart = L_MAX(0, valcenter - valhw);
@@ -926,8 +932,8 @@ PIX       *pixt, *pixd;
         }
     }
 
-    FREE(slut);
-    FREE(vlut);
+    LEPT_FREE(slut);
+    LEPT_FREE(vlut);
     pixDestroy(&pixt);
     return pixd;
 }
@@ -1016,7 +1022,7 @@ PIX       *pixt, *pixd;
         }
     }
 
-    FREE(lined32);
+    LEPT_FREE(lined32);
     pixDestroy(&pixt);
     return pixd;
 }
@@ -1097,7 +1103,7 @@ PIX       *pixt, *pixd;
         }
     }
 
-    FREE(lined32);
+    LEPT_FREE(lined32);
     pixDestroy(&pixt);
     return pixd;
 }
@@ -1178,7 +1184,7 @@ PIX       *pixt, *pixd;
         }
     }
 
-    FREE(lined32);
+    LEPT_FREE(lined32);
     pixDestroy(&pixt);
     return pixd;
 }
@@ -1193,8 +1199,8 @@ PIX       *pixt, *pixd;
  *              height (half height of sliding window)
  *              npeaks (number of peaks to look for)
  *              erasefactor (ratio of erase window size to sliding window size)
- *              &pta (locations of maximum for each integrated peak area)
- *              &natot (integrated peak areas)
+ *              &pta (<return> locations of max for each integrated peak area)
+ *              &natot (<return> integrated peak areas)
  *              &pixa (<optional return> pixa for debugging; NULL to skip)
  *      Return: 0 if OK, 1 on error
  *
@@ -1229,6 +1235,9 @@ PTA      *pta;
 
     PROCNAME("pixFindHistoPeaksHSV");
 
+    if (ppixa) *ppixa = NULL;
+    if (ppta) *ppta = NULL;
+    if (pnatot) *pnatot = NULL;
     if (!pixs || pixGetDepth(pixs) != 32)
         return ERROR_INT("pixs undefined or not 32 bpp", procName, 1);
     if (!ppta || !pnatot)
@@ -1539,6 +1548,9 @@ l_float32  norm;
 
     PROCNAME("convertRGBToYUV");
 
+    if (pyval) *pyval = 0;
+    if (puval) *puval = 0;
+    if (pvval) *pvval = 0;
     if (!pyval || !puval || !pvval)
         return ERROR_INT("&yval, &uval, &vval not all defined", procName, 1);
 
@@ -1583,6 +1595,9 @@ l_float32  norm, ym, um, vm;
 
     PROCNAME("convertYUVToRGB");
 
+    if (prval) *prval = 0;
+    if (pgval) *pgval = 0;
+    if (pbval) *pbval = 0;
     if (!prval || !pgval || !pbval)
         return ERROR_INT("&rval, &gval, &bval not all defined", procName, 1);
 
@@ -1816,6 +1831,9 @@ convertRGBToXYZ(l_int32     rval,
 {
     PROCNAME("convertRGBToXYZ");
 
+    if (pfxval) *pfxval = 0.0;
+    if (pfyval) *pfyval = 0.0;
+    if (pfzval) *pfzval = 0.0;
     if (!pfxval || !pfyval || !pfzval)
         return ERROR_INT("&xval, &yval, &zval not all defined", procName, 1);
 
@@ -1856,7 +1874,10 @@ l_int32  rval, gval, bval;
 
     PROCNAME("convertXYZToRGB");
 
-    if (!prval || !pgval || !pbval)
+    if (prval) *prval = 0;
+    if (pgval) *pgval = 0;
+    if (pbval) *pbval = 0;
+    if (!prval || !pgval ||!pbval)
         return ERROR_INT("&rval, &gval, &bval not all defined", procName, 1);
     *prval = *pgval = *pbval = 0;
 
@@ -2036,6 +2057,9 @@ l_float32  xn, yn, zn, fx, fy, fz;
 
     PROCNAME("convertXYZToLAB");
 
+    if (plval) *plval = 0.0;
+    if (paval) *paval = 0.0;
+    if (pbval) *pbval = 0.0;
     if (!plval || !paval || !pbval)
         return ERROR_INT("&lval, &aval, &bval not all defined", procName, 1);
 
@@ -2076,6 +2100,9 @@ l_float32  zw = 277.69;  /* z component corresponding to rgb white */
 
     PROCNAME("convertLABToXYZ");
 
+    if (pxval) *pxval = 0.0;
+    if (pyval) *pyval = 0.0;
+    if (pzval) *pzval = 0.0;
     if (!pxval || !pyval || !pzval)
         return ERROR_INT("&xval, &yval, &zval not all defined", procName, 1);
 
@@ -2273,6 +2300,9 @@ l_float32  fxval, fyval, fzval;
 
     PROCNAME("convertRGBToLAB");
 
+    if (pflval) *pflval = 0.0;
+    if (pfaval) *pfaval = 0.0;
+    if (pfbval) *pfbval = 0.0;
     if (!pflval || !pfaval || !pfbval)
         return ERROR_INT("&flval, &faval, &fbval not all defined", procName, 1);
 
@@ -2305,6 +2335,9 @@ l_float32  fxval, fyval, fzval;
 
     PROCNAME("convertLABToRGB");
 
+    if (prval) *prval = 0;
+    if (pgval) *pgval = 0;
+    if (pbval) *pbval = 0;
     if (!prval || !pgval || !pbval)
         return ERROR_INT("&rval, &gval, &bval not all defined", procName, 1);
 
