@@ -24,7 +24,6 @@
  -  SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *====================================================================*/
 
-
 /*
  *  readfile.c:  reads image on file into memory
  *
@@ -63,43 +62,39 @@
  *          tiff  (including most varieties of compression)
  *          gif
  *          webp
- *  (3) This file format is recognized by the library but reading
- *      is not supported:
- *          jp2 (jpeg2000)
- *  (4) All other file types will get an "unknown format" error.
+ *          jp2 (jpeg 2000)
+ *  (3) Other file types will get an "unknown format" error.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config_auto.h"
+#endif  /* HAVE_CONFIG_H */
+
 #include <string.h>
 #include "allheaders.h"
 
-    /*  choose type of PIX to be generated  */
-enum {
-    READ_24_BIT_COLOR = 0,     /* read in as 24 (really 32) bit pix */
-    CONVERT_TO_PALETTE = 1,    /* convert to 8 bit colormapped pix */
-    READ_GRAY = 2              /* read gray only */
-};
+    /* Output files for ioFormatTest(). */
+static const char *FILE_BMP  =  "/tmp/lept/format/file.bmp";
+static const char *FILE_PNG  =  "/tmp/lept/format/file.png";
+static const char *FILE_PNM  =  "/tmp/lept/format/file.pnm";
+static const char *FILE_G3   =  "/tmp/lept/format/file_g3.tif";
+static const char *FILE_G4   =  "/tmp/lept/format/file_g4.tif";
+static const char *FILE_RLE  =  "/tmp/lept/format/file_rle.tif";
+static const char *FILE_PB   =  "/tmp/lept/format/file_packbits.tif";
+static const char *FILE_LZW  =  "/tmp/lept/format/file_lzw.tif";
+static const char *FILE_ZIP  =  "/tmp/lept/format/file_zip.tif";
+static const char *FILE_TIFF =  "/tmp/lept/format/file.tif";
+static const char *FILE_JPG  =  "/tmp/lept/format/file.jpg";
+static const char *FILE_GIF  =  "/tmp/lept/format/file.gif";
+static const char *FILE_WEBP =  "/tmp/lept/format/file.webp";
+static const char *FILE_JP2K =  "/tmp/lept/format/file.jp2";
 
-    /* Output files for ioFormatTest().
-     * Note that the test for jpeg is not yet implemented */
-static const char *FILE_BMP  =  "/tmp/junkout.bmp";
-static const char *FILE_PNG  =  "/tmp/junkout.png";
-static const char *FILE_PNM  =  "/tmp/junkout.pnm";
-static const char *FILE_G3   =  "/tmp/junkout_g3.tif";
-static const char *FILE_G4   =  "/tmp/junkout_g4.tif";
-static const char *FILE_RLE  =  "/tmp/junkout_rle.tif";
-static const char *FILE_PB   =  "/tmp/junkout_packbits.tif";
-static const char *FILE_LZW  =  "/tmp/junkout_lzw.tif";
-static const char *FILE_ZIP  =  "/tmp/junkout_zip.tif";
-static const char *FILE_TIFF =  "/tmp/junkout.tif";
-static const char *FILE_JPG  =  "/tmp/junkout.jpg";
-
-    /* I found these from the source code to the unix file */
-    /* command. man 1 file */
 static const unsigned char JP2K_CODESTREAM[4] = { 0xff, 0x4f, 0xff, 0x51 };
 static const unsigned char JP2K_IMAGE_DATA[12] = { 0x00, 0x00, 0x00, 0x0C,
                                                    0x6A, 0x50, 0x20, 0x20,
                                                    0x0D, 0x0A, 0x87, 0x0A };
 
+
 /*---------------------------------------------------------------------*
  *          Top-level functions for reading images from file           *
  *---------------------------------------------------------------------*/
@@ -192,21 +187,15 @@ PIX   *pix;
     if (!filename)
         return (PIX *)ERROR_PTR("filename not defined", procName, NULL);
 
-    if ((fp = fopenReadStream(filename)) == NULL)
-        return (PIX *)ERROR_PTR("image file not found", procName, NULL);
+    if ((fp = fopenReadStream(filename)) == NULL) {
+        L_ERROR("image file not found: %s\n", procName, filename);
+        return NULL;
+    }
     if ((pix = pixReadStream(fp, 0)) == NULL) {
         fclose(fp);
         return (PIX *)ERROR_PTR("pix not read", procName, NULL);
     }
-
-        /* Close the stream except if GIF under windows, because
-         * DGifCloseFile() closes the windows file stream! */
-    if (pixGetInputFormat(pix) != IFF_GIF)
-        fclose(fp);
-#ifndef _WIN32
-    else  /* gif file */
-        fclose(fp);
-#endif  /* ! _WIN32 */
+    fclose(fp);
 
     return pix;
 }
@@ -334,13 +323,12 @@ PIX      *pix;
         break;
 
     case IFF_JFIF_JPEG:
-        if ((pix = pixReadStreamJpeg(fp, READ_24_BIT_COLOR, 1, NULL, hint))
-                == NULL)
+        if ((pix = pixReadStreamJpeg(fp, 0, 1, NULL, hint)) == NULL)
             return (PIX *)ERROR_PTR( "jpeg: no pix returned", procName, NULL);
         ret = fgetJpegComment(fp, &comment);
         if (!ret && comment)
             pixSetText(pix, (char *)comment);
-        FREE(comment);
+        LEPT_FREE(comment);
         break;
 
     case IFF_PNG:
@@ -370,7 +358,8 @@ PIX      *pix;
         break;
 
     case IFF_JP2:
-        return (PIX *)ERROR_PTR("jp2: format not supported", procName, NULL);
+        if ((pix = pixReadStreamJp2k(fp, 1, NULL, 0, 0)) == NULL)
+            return (PIX *)ERROR_PTR("jp2: no pix returned", procName, NULL);
         break;
 
     case IFF_WEBP:
@@ -503,8 +492,7 @@ PIX     *pix;
         break;
 
     case IFF_JP2:
-        ret = readHeaderJp2k(filename, &w, &h, &spp);
-        bps = 8;
+        ret = readHeaderJp2k(filename, &w, &h, &bps, &spp);
         break;
 
     case IFF_WEBP:
@@ -770,11 +758,13 @@ l_int32  format;
  *  Notes:
  *      (1) This is a variation of pixReadStream(), where the data is read
  *          from a memory buffer rather than a file.
- *      (2) On windows, this will only read tiff formatted files from
- *          memory.  For other formats, it requires fmemopen(3).
- *          Attempts to read those formats will fail at runtime.
- *      (3) findFileFormatBuffer() requires up to 8 bytes to decide on
- *          the format.  That determines the constraint here.
+ *      (2) On windows, this only reads tiff formatted files directly from
+ *          memory.  For other formats, it write to a temp file and
+ *          decompress from file.
+ *      (3) findFileFormatBuffer() requires up to 12 bytes to decide on
+ *          the format.  That determines the constraint here.  But in
+ *          fact the data must contain the entire compressed string for
+ *          the image.
  */
 PIX *
 pixReadMem(const l_uint8  *data,
@@ -787,8 +777,8 @@ PIX     *pix;
 
     if (!data)
         return (PIX *)ERROR_PTR("data not defined", procName, NULL);
-    if (size < 8)
-        return (PIX *)ERROR_PTR("size < 8", procName, NULL);
+    if (size < 12)
+        return (PIX *)ERROR_PTR("size < 12", procName, NULL);
     pix = NULL;
 
     findFileFormatBuffer(data, &format);
@@ -800,8 +790,7 @@ PIX     *pix;
         break;
 
     case IFF_JFIF_JPEG:
-        if ((pix = pixReadMemJpeg(data, size, READ_24_BIT_COLOR, 1, NULL, 0))
-                == NULL)
+        if ((pix = pixReadMemJpeg(data, size, 0, 1, NULL, 0)) == NULL)
             return (PIX *)ERROR_PTR( "jpeg: no pix returned", procName, NULL);
         break;
 
@@ -833,7 +822,13 @@ PIX     *pix;
         break;
 
     case IFF_JP2:
-        return (PIX *)ERROR_PTR("jp2: format not supported", procName, NULL);
+        if ((pix = pixReadMemJp2k(data, size, 1, NULL, 0, 0)) == NULL)
+            return (PIX *)ERROR_PTR("jp2k: no pix returned", procName, NULL);
+        break;
+
+    case IFF_WEBP:
+        if ((pix = pixReadMemWebP(data, size)) == NULL)
+            return (PIX *)ERROR_PTR("webp: no pix returned", procName, NULL);
         break;
 
     case IFF_SPIX:
@@ -872,14 +867,15 @@ PIX     *pix;
  *      Return: 0 if OK, 1 on error
  *
  *  Notes:
- *      (1) This reads the actual headers for jpeg, png, tiff and pnm.
+ *      (1) This reads the actual headers for jpeg, png, tiff, jp2k and pnm.
  *          For bmp and gif, we cheat and read all the data into a pix,
  *          from which we extract the "header" information.
- *      (2) On windows, this will only read tiff formatted files from
- *          memory.  For other formats, it requires fmemopen(3).
- *          Attempts to read those formats will fail at runtime.
+ *      (2) The amount of data required depends on the format.  For
+ *          png, it requires less than 30 bytes, but for jpeg it can
+ *          require most of the compressed file.  In practice, the data
+ *          is typically the entire compressed file in memory.
  *      (3) findFileFormatBuffer() requires up to 8 bytes to decide on
- *          the format.  That determines the constraint here.
+ *          the format, which we require.
  */
 l_int32
 pixReadHeaderMem(const l_uint8  *data,
@@ -930,7 +926,7 @@ PIX     *pix;
         break;
 
     case IFF_PNG:
-        ret = sreadHeaderPng(data, &w, &h, &bps, &spp, &iscmap);
+        ret = readHeaderMemPng(data, size, &w, &h, &bps, &spp, &iscmap);
         if (ret)
             return ERROR_INT( "png: no header info returned", procName, 1);
         break;
@@ -950,7 +946,7 @@ PIX     *pix;
         break;
 
     case IFF_PNM:
-        ret = sreadHeaderPnm(data, size, &w, &h, &d, &type, &bps, &spp);
+        ret = readHeaderMemPnm(data, size, &w, &h, &d, &type, &bps, &spp);
         if (ret)
             return ERROR_INT( "pnm: no header info returned", procName, 1);
         break;
@@ -966,8 +962,12 @@ PIX     *pix;
         break;
 
     case IFF_JP2:
-        ret = sreadHeaderJp2k(data, size, &w, &h, &spp);
+        ret = readHeaderMemJp2k(data, size, &w, &h, &bps, &spp);
+        break;
+
+    case IFF_WEBP:
         bps = 8;
+        ret = readHeaderMemWebP(data, size, &w, &h, &spp);
         break;
 
     case IFF_SPIX:
@@ -995,10 +995,6 @@ PIX     *pix;
 /*---------------------------------------------------------------------*
  *             Test function for I/O with different formats            *
  *---------------------------------------------------------------------*/
-#ifdef HAVE_CONFIG_H
-#include "config_auto.h"
-#endif  /* HAVE_CONFIG_H */
-
 /*!
  *  ioFormatTest()
  *
@@ -1007,7 +1003,7 @@ PIX     *pix;
  *
  *  Notes:
  *      (1) This writes and reads a set of output files losslessly
- *          in different formats to /tmp, and tests that the
+ *          in different formats to /tmp/format/, and tests that the
  *          result before and after is unchanged.
  *      (2) This should work properly on input images of any depth,
  *          with and without colormaps.
@@ -1022,17 +1018,31 @@ PIX     *pix;
 l_int32
 ioFormatTest(const char  *filename)
 {
-l_int32   d, equal, problems;
-PIX      *pixs, *pixc, *pixt, *pixt2;
-PIXCMAP  *cmap;
+l_int32    w, h, d, depth, equal, problems;
+l_float32  diff;
+BOX       *box;
+PIX       *pixs, *pixc, *pix1, *pix2;
+PIXCMAP   *cmap;
 
     PROCNAME("ioFormatTest");
 
     if (!filename)
         return ERROR_INT("filename not defined", procName, 1);
 
-    if ((pixs = pixRead(filename)) == NULL)
-        return ERROR_INT("pixs not made", procName, 1);
+        /* Read the input file and limit the size */
+    if ((pix1 = pixRead(filename)) == NULL)
+        return ERROR_INT("pix1 not made", procName, 1);
+    pixGetDimensions(pix1, &w, &h, NULL);
+    if (w > 250 && h > 250) {  /* take the central 250 x 250 region */
+        box = boxCreate(w / 2 - 125, h / 2 - 125, 250, 250);
+        pixs = pixClipRectangle(pix1, box, NULL);
+        boxDestroy(&box);
+    } else {
+        pixs = pixClone(pix1);
+    }
+    pixDestroy(&pix1);
+
+    lept_mkdir("lept/format");
 
         /* Note that the reader automatically removes colormaps
          * from 1 bpp BMP images, but not from 8 bpp BMP images.
@@ -1060,30 +1070,30 @@ PIXCMAP  *cmap;
     if (d == 1 || d == 8) {
         L_INFO("write/read bmp\n", procName);
         pixWrite(FILE_BMP, pixc, IFF_BMP);
-        pixt = pixRead(FILE_BMP);
+        pix1 = pixRead(FILE_BMP);
         if (!cmap)
-            pixt2 = pixRemoveColormap(pixt, REMOVE_CMAP_BASED_ON_SRC);
+            pix2 = pixRemoveColormap(pix1, REMOVE_CMAP_BASED_ON_SRC);
         else
-            pixt2 = pixClone(pixt);
-        pixEqual(pixc, pixt2, &equal);
+            pix2 = pixClone(pix1);
+        pixEqual(pixc, pix2, &equal);
         if (!equal) {
-            L_INFO("   **** bad bmp image ****\n", procName);
+            L_INFO("   **** bad bmp image: d = %d ****\n", procName, d);
             problems = TRUE;
         }
-        pixDestroy(&pixt);
-        pixDestroy(&pixt2);
+        pixDestroy(&pix1);
+        pixDestroy(&pix2);
     }
 
     if (d == 2 || d == 4 || d == 32) {
         L_INFO("write/read bmp\n", procName);
         pixWrite(FILE_BMP, pixc, IFF_BMP);
-        pixt = pixRead(FILE_BMP);
-        pixEqual(pixc, pixt, &equal);
+        pix1 = pixRead(FILE_BMP);
+        pixEqual(pixc, pix1, &equal);
         if (!equal) {
-            L_INFO("   **** bad bmp image ****\n", procName);
+            L_INFO("   **** bad bmp image: d = %d ****\n", procName, d);
             problems = TRUE;
         }
-        pixDestroy(&pixt);
+        pixDestroy(&pix1);
     }
 
         /* ----------------------- PNG -------------------------- */
@@ -1093,13 +1103,13 @@ PIXCMAP  *cmap;
     if (d != 16) {
         L_INFO("write/read png\n", procName);
         pixWrite(FILE_PNG, pixc, IFF_PNG);
-        pixt = pixRead(FILE_PNG);
-        pixEqual(pixc, pixt, &equal);
+        pix1 = pixRead(FILE_PNG);
+        pixEqual(pixc, pix1, &equal);
         if (!equal) {
-            L_INFO("   **** bad png image ****\n", procName);
+            L_INFO("   **** bad png image: d = %d ****\n", procName, d);
             problems = TRUE;
         }
-        pixDestroy(&pixt);
+        pixDestroy(&pix1);
     }
 #endif  /* HAVE_LIBPNG */
 
@@ -1117,77 +1127,81 @@ PIXCMAP  *cmap;
         /* tiff uncompressed works for all pixel depths */
     L_INFO("write/read uncompressed tiff\n", procName);
     pixWrite(FILE_TIFF, pixc, IFF_TIFF);
-    pixt = pixRead(FILE_TIFF);
-    pixEqual(pixc, pixt, &equal);
+    pix1 = pixRead(FILE_TIFF);
+    pixEqual(pixc, pix1, &equal);
     if (!equal) {
-        L_INFO("   **** bad tiff uncompressed image ****\n", procName);
+        L_INFO("   **** bad tiff uncompressed image: d = %d ****\n",
+               procName, d);
         problems = TRUE;
     }
-    pixDestroy(&pixt);
+    pixDestroy(&pix1);
 
         /* tiff lzw works for all pixel depths */
     L_INFO("write/read lzw compressed tiff\n", procName);
     pixWrite(FILE_LZW, pixc, IFF_TIFF_LZW);
-    pixt = pixRead(FILE_LZW);
-    pixEqual(pixc, pixt, &equal);
+    pix1 = pixRead(FILE_LZW);
+    pixEqual(pixc, pix1, &equal);
     if (!equal) {
-        L_INFO("   **** bad tiff lzw compressed image ****\n", procName);
+        L_INFO("   **** bad tiff lzw compressed image: d = %d ****\n",
+               procName, d);
         problems = TRUE;
     }
-    pixDestroy(&pixt);
+    pixDestroy(&pix1);
 
         /* tiff adobe deflate (zip) works for all pixel depths */
     L_INFO("write/read zip compressed tiff\n", procName);
     pixWrite(FILE_ZIP, pixc, IFF_TIFF_ZIP);
-    pixt = pixRead(FILE_ZIP);
-    pixEqual(pixc, pixt, &equal);
+    pix1 = pixRead(FILE_ZIP);
+    pixEqual(pixc, pix1, &equal);
     if (!equal) {
-        L_INFO("   **** bad tiff zip compressed image ****\n", procName);
+        L_INFO("   **** bad tiff zip compressed image: d = %d ****\n",
+               procName, d);
         problems = TRUE;
     }
-    pixDestroy(&pixt);
+    pixDestroy(&pix1);
 
         /* tiff g4, g3, rle and packbits work for 1 bpp */
     if (d == 1) {
         L_INFO("write/read g4 compressed tiff\n", procName);
         pixWrite(FILE_G4, pixc, IFF_TIFF_G4);
-        pixt = pixRead(FILE_G4);
-        pixEqual(pixc, pixt, &equal);
+        pix1 = pixRead(FILE_G4);
+        pixEqual(pixc, pix1, &equal);
         if (!equal) {
             L_INFO("   **** bad tiff g4 image ****\n", procName);
             problems = TRUE;
         }
-        pixDestroy(&pixt);
+        pixDestroy(&pix1);
 
         L_INFO("write/read g3 compressed tiff\n", procName);
         pixWrite(FILE_G3, pixc, IFF_TIFF_G3);
-        pixt = pixRead(FILE_G3);
-        pixEqual(pixc, pixt, &equal);
+        pix1 = pixRead(FILE_G3);
+        pixEqual(pixc, pix1, &equal);
         if (!equal) {
             L_INFO("   **** bad tiff g3 image ****\n", procName);
             problems = TRUE;
         }
-        pixDestroy(&pixt);
+        pixDestroy(&pix1);
 
         L_INFO("write/read rle compressed tiff\n", procName);
         pixWrite(FILE_RLE, pixc, IFF_TIFF_RLE);
-        pixt = pixRead(FILE_RLE);
-        pixEqual(pixc, pixt, &equal);
+        pix1 = pixRead(FILE_RLE);
+        pixEqual(pixc, pix1, &equal);
         if (!equal) {
-            L_INFO("   **** bad tiff rle image ****\n", procName);
+            L_INFO("   **** bad tiff rle image: d = %d ****\n", procName, d);
             problems = TRUE;
         }
-        pixDestroy(&pixt);
+        pixDestroy(&pix1);
 
         L_INFO("write/read packbits compressed tiff\n", procName);
         pixWrite(FILE_PB, pixc, IFF_TIFF_PACKBITS);
-        pixt = pixRead(FILE_PB);
-        pixEqual(pixc, pixt, &equal);
+        pix1 = pixRead(FILE_PB);
+        pixEqual(pixc, pix1, &equal);
         if (!equal) {
-            L_INFO("   **** bad tiff packbits image ****\n", procName);
+            L_INFO("   **** bad tiff packbits image: d = %d ****\n",
+                   procName, d);
             problems = TRUE;
         }
-        pixDestroy(&pixt);
+        pixDestroy(&pix1);
     }
 #endif  /* HAVE_LIBTIFF */
 
@@ -1199,18 +1213,113 @@ PIXCMAP  *cmap;
          * we must remove the colormap from pixc before testing.  */
     L_INFO("write/read pnm\n", procName);
     pixWrite(FILE_PNM, pixc, IFF_PNM);
-    pixt = pixRead(FILE_PNM);
+    pix1 = pixRead(FILE_PNM);
     if (cmap)
-        pixt2 = pixRemoveColormap(pixc, REMOVE_CMAP_BASED_ON_SRC);
+        pix2 = pixRemoveColormap(pixc, REMOVE_CMAP_BASED_ON_SRC);
     else
-        pixt2 = pixClone(pixc);
-    pixEqual(pixt, pixt2, &equal);
+        pix2 = pixClone(pixc);
+    pixEqual(pix1, pix2, &equal);
     if (!equal) {
-        L_INFO("   **** bad pnm image ****\n", procName);
+        L_INFO("   **** bad pnm image: d = %d ****\n", procName, d);
         problems = TRUE;
     }
-    pixDestroy(&pixt);
-    pixDestroy(&pixt2);
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
+
+        /* ----------------------- GIF -------------------------- */
+#if HAVE_LIBGIF
+        /* GIF works for only 1 and 8 bpp, colormapped */
+    if (d != 8 || !cmap)
+        pix1 = pixConvertTo8(pixc, 1);
+    else
+        pix1 = pixClone(pixc);
+    L_INFO("write/read gif\n", procName);
+    pixWrite(FILE_GIF, pix1, IFF_GIF);
+    pix2 = pixRead(FILE_GIF);
+    pixEqual(pix1, pix2, &equal);
+    if (!equal) {
+        L_INFO("   **** bad gif image: d = %d ****\n", procName, d);
+        problems = TRUE;
+    }
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
+#endif  /* HAVE_LIBGIF */
+
+        /* ----------------------- JPEG ------------------------- */
+#if HAVE_LIBJPEG
+        /* JPEG works for only 8 bpp gray and rgb */
+    if (cmap || d > 8)
+        pix1 = pixConvertTo32(pixc);
+    else
+        pix1 = pixConvertTo8(pixc, 0);
+    depth = pixGetDepth(pix1);
+    L_INFO("write/read jpeg\n", procName);
+    pixWrite(FILE_JPG, pix1, IFF_JFIF_JPEG);
+    pix2 = pixRead(FILE_JPG);
+    if (depth == 8) {
+        pixCompareGray(pix1, pix2, L_COMPARE_ABS_DIFF, 0, NULL, &diff,
+                       NULL, NULL);
+    } else {
+        pixCompareRGB(pix1, pix2, L_COMPARE_ABS_DIFF, 0, NULL, &diff,
+                      NULL, NULL);
+    }
+    if (diff > 8.0) {
+        L_INFO("   **** bad jpeg image: d = %d, diff = %5.2f ****\n",
+               procName, depth, diff);
+        problems = TRUE;
+    }
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
+#endif  /* HAVE_LIBJPEG */
+
+        /* ----------------------- WEBP ------------------------- */
+#if HAVE_LIBWEBP
+        /* WEBP works for rgb and rgba */
+    if (cmap || d <= 16)
+        pix1 = pixConvertTo32(pixc);
+    else
+        pix1 = pixClone(pixc);
+    depth = pixGetDepth(pix1);
+    L_INFO("write/read webp\n", procName);
+    pixWrite(FILE_WEBP, pix1, IFF_WEBP);
+    pix2 = pixRead(FILE_WEBP);
+    pixCompareRGB(pix1, pix2, L_COMPARE_ABS_DIFF, 0, NULL, &diff, NULL, NULL);
+    if (diff > 5.0) {
+        L_INFO("   **** bad webp image: d = %d, diff = %5.2f ****\n",
+               procName, depth, diff);
+        problems = TRUE;
+    }
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
+#endif  /* HAVE_LIBWEBP */
+
+        /* ----------------------- JP2K ------------------------- */
+#if HAVE_LIBJP2K
+        /* JP2K works for only 8 bpp gray, rgb and rgba */
+    if (cmap || d > 8)
+        pix1 = pixConvertTo32(pixc);
+    else
+        pix1 = pixConvertTo8(pixc, 0);
+    depth = pixGetDepth(pix1);
+    L_INFO("write/read jp2k\n", procName);
+    pixWrite(FILE_JP2K, pix1, IFF_JP2);
+    pix2 = pixRead(FILE_JP2K);
+    if (depth == 8) {
+        pixCompareGray(pix1, pix2, L_COMPARE_ABS_DIFF, 0, NULL, &diff,
+                       NULL, NULL);
+    } else {
+        pixCompareRGB(pix1, pix2, L_COMPARE_ABS_DIFF, 0, NULL, &diff,
+                      NULL, NULL);
+    }
+    fprintf(stderr, "diff = %7.3f\n", diff);
+    if (diff > 7.0) {
+        L_INFO("   **** bad jp2k image: d = %d, diff = %5.2f ****\n",
+               procName, depth, diff);
+        problems = TRUE;
+    }
+    pixDestroy(&pix1);
+    pixDestroy(&pix2);
+#endif  /* HAVE_LIBJP2K */
 
     if (problems == FALSE)
         L_INFO("All formats read and written OK!\n", procName);
@@ -1219,3 +1328,4 @@ PIXCMAP  *cmap;
     pixDestroy(&pixs);
     return problems;
 }
+
